==> orchestra-axis-felix-4.4.0.zip: orchestra-axis-felix-4.4.0/resources/db-schemas/history/org.hibernate.dialect.PostgreSQLDialect-drop.sql <==
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_PARENT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_TH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_FH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_EXCEPTION_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_WAIT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CHILD_FK;
alter table BPEL_ACTIVITY_INST drop constraint SCOPE_INST_EVT_FK;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19F1C5FAB0;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D1982112BDD;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19614874B5;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19DE3B31AF;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19D4D0807A;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table COPY_FULL_IMPL drop constraint COPY_LST_FK;
alter table CORR_DEF_ drop constraint REC_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint IVK_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint RP_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint ON_EVT_CORR_FK;
alter table CORR_DEF_ drop constraint ON_MSG_CORR_FK;
alter table CS_INIT_FULL_IMPL drop constraint SCOPE_INST_CS_FK;
alter table ELSEIF_DEF_ drop constraint IF_ELSEIF_LST_FK;
alter table ELSEIF_DEF_ drop constraint FK4BC7A7A366DBBFD7;
alter table FRM_PRT_DEF_ drop constraint REC_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint IVK_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint ON_MSG_FRM_PRT_FK;
alter table FRM_PRT_DEF_ drop constraint ON_EVT_FRM_PRT_FK;
alter table FROM_TO_FULL drop constraint FROM_LST_FK;
alter table FROM_TO_FULL drop constraint TO_LST_FK;
alter table NOVA_CS_INST_PROP drop constraint CS_INST_PROP_FK;
alter table ON_ALRM_DEF_ drop constraint PK_DF_ON_AL_FK;
alter table ON_ALRM_DEF_ drop constraint FK5B79CBB3735C61C7;
alter table ON_ALRM_DEF_ drop constraint SCOPE_DEF_ALARMS_FK;
alter table ON_EVT_DEF_ drop constraint FKC013947699EA93C4;
alter table ON_EVT_DEF_ drop constraint SCOPE_DEF_EVTS_FK;
alter table ON_MSG_DEF_ drop constraint PK_DF_ON_MSG_FK;
alter table ON_MSG_DEF_ drop constraint FK4A3B4998A6853462;
alter table PART_LNK_DEF_ drop constraint SCOPE_DEF_PL_FK;
alter table PLNK_UPDATE_FULL_IMPL drop constraint SCOPE_INST_PLNK_FK;
alter table PROCESS_INST_STATE_UPDATE_ drop constraint PROCESS_INST_STATE_FK;
alter table SCOPE_STATE_UPDATE_ drop constraint SCOPE_INST_STATE_FK;
alter table SRC_FULL_IMPL drop constraint SRC_LST_FK;
alter table TGT_FULL_IMPL drop constraint TRGT_LST_FK;
alter table TO_PRT_DEF_ drop constraint RP_TO_PT_LST_FK;
alter table TO_PRT_DEF_ drop constraint IVK_TO_PT_LST_FK;
alter table TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table VAR_DEF_ drop constraint SCOPE_DEF_VAR_FK;
alter table VAR_DEF_CS_ drop constraint SCOPE_DEF_CS_FK;
alter table VAR_UPDATE_FULL_IMPL drop constraint SCOPE_INST_VAR_FK;
alter table WAITING_FULL_IMPL drop constraint PICK_WAIT_FK;
alter table linkList drop constraint FLOW_LINKS_FK;
alter table messageExchanges drop constraint SCOPE_DEF_M_E_FK;
alter table properties drop constraint CORR_ST_DEF_FK;
drop table BPEL_ACTIVITY_INST;
drop table BPEL_BASE_ACTIVITY_DEF;
drop table BPEL_FAULT_;
drop table BPEL_REC;
drop table COPY_FULL_IMPL;
drop table CORR_DEF_;
drop table CS_INIT_FULL_IMPL;
drop table ELSEIF_DEF_;
drop table FRM_PRT_DEF_;
drop table FROM_TO_FULL;
drop table NOVA_CS_INST_PROP;
drop table NOVA_NAMESPACE;
drop table ON_ALRM_DEF_;
drop table ON_EVT_DEF_;
drop table ON_MSG_DEF_;
drop table PART_LNK_DEF_;
drop table PLNK_UPDATE_FULL_IMPL;
drop table PROCESS_INST_STATE_UPDATE_;
drop table SCOPE_STATE_UPDATE_;
drop table SRC_FULL_IMPL;
drop table TGT_FULL_IMPL;
drop table TO_PRT_DEF_;
drop table TR_COND_UPD_;
drop table VAR_DEF_;
drop table VAR_DEF_CS_;
drop table VAR_UPDATE_FULL_IMPL;
drop table WAITING_FULL_IMPL;
drop table linkList;
drop table messageExchanges;
drop table properties;
drop sequence hibernate_sequence;

==> orchestra-axis-felix-4.6.0.zip: orchestra-axis-felix-4.6.0/resources/db-schemas/history/org.hibernate.dialect.PostgreSQLDialect-drop.sql <==
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_PARENT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_TH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_FH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_EXCEPTION_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_WAIT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CHILD_FK;
alter table BPEL_ACTIVITY_INST drop constraint SCOPE_INST_EVT_FK;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19F1C5FAB0;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D1982112BDD;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19614874B5;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19DE3B31AF;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19D4D0807A;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table COPY_FULL_IMPL drop constraint COPY_LST_FK;
alter table CORR_DEF_ drop constraint REC_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint IVK_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint RP_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint ON_EVT_CORR_FK;
alter table CORR_DEF_ drop constraint ON_MSG_CORR_FK;
alter table CS_INIT_FULL_IMPL drop constraint SCOPE_INST_CS_FK;
alter table ELSEIF_DEF_ drop constraint IF_ELSEIF_LST_FK;
alter table ELSEIF_DEF_ drop constraint FK4BC7A7A366DBBFD7;
alter table FRM_PRT_DEF_ drop constraint REC_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint IVK_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint ON_MSG_FRM_PRT_FK;
alter table FRM_PRT_DEF_ drop constraint ON_EVT_FRM_PRT_FK;
alter table FROM_TO_FULL drop constraint FROM_LST_FK;
alter table FROM_TO_FULL drop constraint TO_LST_FK;
alter table NOVA_CS_INST_PROP drop constraint CS_INST_PROP_FK;
alter table ON_ALRM_DEF_ drop constraint PK_DF_ON_AL_FK;
alter table ON_ALRM_DEF_ drop constraint FK5B79CBB3735C61C7;
alter table ON_ALRM_DEF_ drop constraint SCOPE_DEF_ALARMS_FK;
alter table ON_EVT_DEF_ drop constraint FKC013947699EA93C4;
alter table ON_EVT_DEF_ drop constraint SCOPE_DEF_EVTS_FK;
alter table ON_MSG_DEF_ drop constraint PK_DF_ON_MSG_FK;
alter table ON_MSG_DEF_ drop constraint FK4A3B4998A6853462;
alter table PART_LNK_DEF_ drop constraint SCOPE_DEF_PL_FK;
alter table PLNK_UPDATE_FULL_IMPL drop constraint SCOPE_INST_PLNK_FK;
alter table PROCESS_INST_STATE_UPDATE_ drop constraint PROCESS_INST_STATE_FK;
alter table PROC_STATE_UPD_ drop constraint PROCESS_STATE_FK;
alter table SCOPE_STATE_UPDATE_ drop constraint SCOPE_INST_STATE_FK;
alter table SRC_FULL_IMPL drop constraint SRC_LST_FK;
alter table TGT_FULL_IMPL drop constraint TRGT_LST_FK;
alter table TO_PRT_DEF_ drop constraint RP_TO_PT_LST_FK;
alter table TO_PRT_DEF_ drop constraint IVK_TO_PT_LST_FK;
alter table TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table VAR_DEF_ drop constraint SCOPE_DEF_VAR_FK;
alter table VAR_DEF_CS_ drop constraint SCOPE_DEF_CS_FK;
alter table VAR_UPDATE_FULL_IMPL drop constraint SCOPE_INST_VAR_FK;
alter table WAITING_FULL_IMPL drop constraint PICK_WAIT_FK;
alter table linkList drop constraint FLOW_LINKS_FK;
alter table messageExchanges drop constraint SCOPE_DEF_M_E_FK;
alter table properties drop constraint CORR_ST_DEF_FK;
drop table BPEL_ACTIVITY_INST cascade;
drop table BPEL_BASE_ACTIVITY_DEF cascade;
drop table BPEL_FAULT_ cascade;
drop table BPEL_REC cascade;
drop table COPY_FULL_IMPL cascade;
drop table CORR_DEF_ cascade;
drop table CS_INIT_FULL_IMPL cascade;
drop table ELSEIF_DEF_ cascade;
drop table FRM_PRT_DEF_ cascade;
drop table FROM_TO_FULL cascade;
drop table NOVA_CS_INST_PROP cascade;
drop table NOVA_NAMESPACE cascade;
drop table ON_ALRM_DEF_ cascade;
drop table ON_EVT_DEF_ cascade;
drop table ON_MSG_DEF_ cascade;
drop table PART_LNK_DEF_ cascade;
drop table PLNK_UPDATE_FULL_IMPL cascade;
drop table PROCESS_INST_STATE_UPDATE_ cascade;
drop table PROC_STATE_UPD_ cascade;
drop table SCOPE_STATE_UPDATE_ cascade;
drop table SRC_FULL_IMPL cascade;
drop table TGT_FULL_IMPL cascade;
drop table TO_PRT_DEF_ cascade;
drop table TR_COND_UPD_ cascade;
drop table VAR_DEF_ cascade;
drop table VAR_DEF_CS_ cascade;
drop table VAR_UPDATE_FULL_IMPL cascade;
drop table WAITING_FULL_IMPL cascade;
drop table linkList cascade;
drop table messageExchanges cascade;
drop table properties cascade;
drop table orchestra_sequences cascade;
